cgexplore.terms.TargetMartiniAngle
==================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetMartiniAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetMartiniAngle.human_readable
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetMartiniAngle.type1
      ~TargetMartiniAngle.type2
      ~TargetMartiniAngle.type3
      ~TargetMartiniAngle.element1
      ~TargetMartiniAngle.element2
      ~TargetMartiniAngle.element3
      ~TargetMartiniAngle.funct
      ~TargetMartiniAngle.angle
      ~TargetMartiniAngle.angle_k
   
   